@@ -14,14 +14,14 @@ head(malayrootwords)
 
 ## -----------------------------------------------------------------------------
 
-stem_malay(Word = "banyaknya", dictionary = malayrootwords)
+stem_malay(word = "banyaknya", dictionary = malayrootwords)
 
 
 ## -----------------------------------------------------------------------------
 
 x <- data.frame(text = c("banyaknya","sangat","terkedu", "pengetahuan"))
 
-stem_malay(Word = x, 
+stem_malay(word = x, 
           dictionary = malayrootwords, 
           col_feature1 = "text")
 
@@ -35,3 +35,8 @@ remove_url(x)
 
 
 
+## -----------------------------------------------------------------------------
+
+head(malaystopwords)
+
+
